@@ -6,10 +6,11 @@ from __future__ import print_function, absolute_import
 
 from ..six import StringIO
 from . import types
-from .values import Block, Function, Value, Constant, MetaDataString, AttributeSet
+from .values import (Block, Function, Value, NamedValue, Constant,
+                     MetaDataString, AttributeSet)
 
 
-class Instruction(Value):
+class Instruction(NamedValue):
     def __init__(self, parent, typ, opname, operands, name='', flags=()):
         super(Instruction, self).__init__(parent, typ, name=name)
         assert isinstance(parent, Block)
@@ -56,6 +57,11 @@ class Instruction(Value):
                 ops.append(new if op is old else op)
             self.operands = tuple(ops)
 
+    def __repr__(self):
+        return "<ir.%s %r of type '%s', opname %r, operands %r>" % (
+            self.__class__.__name__, self.name, self.type,
+            self.opname, self.operands)
+
 
 class CallInstrAttributes(AttributeSet):
     _known = frozenset(['noreturn', 'nounwind', 'readonly', 'readnone'])
@@ -232,7 +238,7 @@ class SwitchInstr(PredictableInstr, Terminator):
 
     def add_case(self, val, block):
         assert isinstance(block, Block)
-        if not isinstance(val, (Value, Constant)):
+        if not isinstance(val, Value):
             val = Constant(self.value.type, val)
         self.cases.append((val, block))
 
@@ -627,9 +633,8 @@ class FilterClause(_LandingPadClause):
         super(FilterClause, self).__init__(value)
 
 class LandingPadInstr(Instruction):
-    def __init__(self, parent, typ, personality, name='', cleanup=False):
+    def __init__(self, parent, typ, name='', cleanup=False):
         super(LandingPadInstr, self).__init__(parent, typ, "landingpad", [], name=name)
-        self.personality = personality
         self.cleanup = cleanup
         self.clauses = []
 
@@ -638,11 +643,8 @@ class LandingPadInstr(Instruction):
         self.clauses.append(clause)
 
     def descr(self, buf):
-        pers = self.personality
-        fmt = "landingpad {type} personality {persty} {persfn}{cleanup}{clauses}\n"
+        fmt = "landingpad {type}{cleanup}{clauses}\n"
         buf.append(fmt.format(type=self.type,
-                              persty=pers.type,
-                              persfn=pers.get_reference(),
                               cleanup=' cleanup' if self.cleanup else '',
                               clauses=''.join(["\n      {0}".format(clause)
                                                for clause in self.clauses]),
